@@ -32,7 +32,7 @@
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.14'
+__version__ = '0.15'
 
 
 DEFAULT_TTL = 3600
@@ -195,10 +195,7 @@ class Zone(core_flags.CoreFlags):
     """Sets flags for self.parser"""
     make = self.action == 'Make'
     # All flags
-    if( make ):
-      default_view = u'any'
-    else:
-      default_view = None
+    default_view = None
     self.parser.add_option('-v', '--view-name', action='store',
                            dest='view_name',
                            help='String of view name.', default=default_view)
@@ -293,7 +290,10 @@ class Host(core_flags.CoreFlags):
                              dest='ip_address', default=None,
                              help='Full IP address of machine.',
                              metavar='<ip-address>')
-      self.AddFlagRule('ip_address', required=not_list)
+      if( self.action == 'Make' ):
+        self.AddFlagRule('ip_address', required=not_list, command='add')
+      else:
+        self.AddFlagRule('ip_address', required=not_list)
       self.parser.add_option('-t', '--target', action='store', dest='target',
                              help='String of machine host name. (Not FQDN)',
                              metavar='<target>', default=None)
@@ -302,11 +302,14 @@ class Host(core_flags.CoreFlags):
                              help='Time for host to live before being '
                              'refreshed.', metavar='<ttl>', default=DEFAULT_TTL)
       self.AddFlagRule('ttl', required=False)
+    self.parser.add_option('--cidr-block', action='store', dest='cidr_block',
+                           help='Get target ip address from cidr block '
+                                'automatically.',
+                           metavar='<cidr-block>', default=None)
+    if( self.action == 'Make' ):
+      self.AddFlagRule('cidr_block', required=True, command='findfirst')
     else:
-      self.parser.add_option('--cidr-block', action='store', dest='cidr_block',
-                             help='Range of ip addresses (CIDR block)',
-                             metavar='<cidr-block>', default=None)
-      self.AddFlagRule('cidr_block')
+      self.AddFlagRule('cidr_block', required=False)
     self.parser.add_option('-z', '--zone-name', action='store',
                            dest='zone_name', help='String of the zone name.',
                            metavar='<zone-name>', default=None)
@@ -321,7 +324,7 @@ class Host(core_flags.CoreFlags):
                                  'Example: "internal"'),
                            metavar='<view-name>',
                            default=default_view)
-    self.AddFlagRule('view_name', required=False, command='host')
+    self.AddFlagRule('view_name', required=False)
 
 
 class DnsServer(core_flags.CoreFlags):
@@ -422,6 +425,34 @@ class Hosts(core_flags.CoreFlags):
     self.SetAllFlagRule('file', required=False)
 
 
+class MassAdd(core_flags.CoreFlags):
+  """Command line uphost flags"""
+  def SetDataFlags(self):
+    """Sets flags for self.parser"""
+    self.parser.add_option('--commit', action='store_true', dest='commit',
+                           help='Commits changes of hosts file without '
+                                'confirmation.', default=False)
+    self.parser.add_option('--no-commit', action='store_true', dest='no_commit',
+                           help='Suppresses changes of hosts file.',
+                           default=False)
+    self.AddFlagRule(('no_commit', 'commit'), required=False,
+                     flag_type='independent_args')
+    self.parser.add_option('-z', '--zone-name', action='store',
+                           dest='zone_name', help='String of the zone name.',
+                           metavar='<zone-name>', default=None)
+    self.SetAllFlagRule('zone_name', required=True)
+    self.parser.add_option('-v', '--view-name', action='store', dest='view_name',
+                           help=('String of the view name <view-name>. Example: '
+                                 '"internal"'), metavar='<view-name>',
+                           default='any')
+    self.SetAllFlagRule('view_name', required=True)
+
+    self.parser.add_option('-f', '--file', action='store', dest='file',
+                           help='File name of hosts file to write to database.',
+                           metavar='<file-name>', default='hosts_out')
+    self.SetAllFlagRule('file', required=True)
+
+
 class NamedGlobals(core_flags.CoreFlags):
   """Command line named global flags"""
   def SetDataFlags(self):
@@ -543,7 +574,7 @@ class SetMaintenance(core_flags.CoreFlags):
                      flag_type='independent_args')
 
   def SetActionFlags(self):
-    """Method to set action variable since set maintenance has no action 
+    """Method to set action variable since set maintenance has no action
     class
     """
     self.action = 'SetMaintenance'
@@ -555,7 +586,7 @@ class Bootstrap(core_flags.CoreFlags):
     """Sets flags for self.parser"""
     pass
   def SetActionFlags(self):
-    """Method to set action variable since set maintenance has no action 
+    """Method to set action variable since set maintenance has no action
     class
     """
-    self.action = 'Bootstrap'
+    self.action = 'Bootstrap'
\ No newline at end of file
